@@ -2,7 +2,7 @@ context("wi_th")
 
 test_that("wi_th: with just headers", {
   aa <- stub_request("get", "https://httpbin.org/get") %>%
-    wi_th(headers = list('User-Agent' = 'R'))
+    wi_th(headers = list("User-Agent" = "R"))
 
   expect_is(aa, "StubbedRequest")
   expect_null(aa$body)
@@ -17,14 +17,14 @@ test_that("wi_th: with just headers", {
   expect_equal(aa$method, "get")
   expect_is(aa$uri, "character")
   expect_equal(aa$uri, "https://httpbin.org/get")
-  expect_equal(aa$request_headers, list('User-Agent' = 'R'))
+  expect_equal(aa$request_headers, list("User-Agent" = "R"))
 })
 
 test_that("wi_th: with headers and query", {
   aa <- stub_request("get", "https://httpbin.org/get") %>%
     wi_th(
       query = list(hello = "world"),
-      headers = list('User-Agent' = 'R'))
+      headers = list("User-Agent" = "R"))
 
   expect_is(aa$query, "list")
   expect_is(aa$request_headers, "list")
@@ -50,4 +50,33 @@ test_that("wi_th fails well", {
                "'headers' must be a named list")
   expect_error(wi_th(zzz, headers = list(a = 5, 6)),
                "'headers' must be a named list")
+
+  # only accepts certain set of named things
+  expect_error(wi_th(zzz, a = 5),
+    "'wi_th' only accepts query, body, headers")
+})
+
+test_that("wi_th .list works", {
+  req <- stub_request("post", "https://httpbin.org/post")
+  expect_equal(
+    wi_th(req, .list = list(body = list(foo = "bar"))),
+    wi_th(req, body = list(foo = "bar"))
+  )
+  expect_equal(
+    wi_th(req, .list = list(query = list(a = 3445))),
+    wi_th(req, query = list(a = 3445))
+  )
+  expect_equal(wi_th(req, .list = ), wi_th(req))
+
+  expect_error(wi_th(req, .list = 4), ".list must be of class list")
+  expect_error(wi_th(req, .list = list(a = 5)),
+    "'wi_th' only accepts query, body, headers")
+})
+
+# cleanup
+stub_registry_clear()
+
+context("wi_th_: defunct")
+test_that("wi_th_: defunct", {
+  expect_error(wi_th_(), "wi_th")
 })
